@@ -70,8 +70,8 @@
 # define VTK_MAX_THREADS 64
 
 /* vtkSMPTools back-end */
-#define VTK_SMP_Sequential
-#define VTK_SMP_BACKEND "Sequential"
+#define VTK_SMP_TBB
+#define VTK_SMP_BACKEND "TBB"
 
 /* Whether we require large files support.  */
 #define VTK_REQUIRE_LARGE_FILE_SUPPORT
@@ -91,18 +91,24 @@
 /* Whether MTime should use a 64-bit integer type on 32 bit builds.  */
 /* #undef VTK_USE_64BIT_TIMESTAMPS */
 
-#include "vtkVersionMacros.h" // removed by VTK_LEGACY_REMOVE
+
 
 /* C++ compiler used.  */
 #define VTK_CXX_COMPILER "/usr/lib/distcc/bin/c++"
 
 /* Compatibility settings.  */
-/* #undef VTK_LEGACY_REMOVE */
+#define VTK_LEGACY_REMOVE
 /* #undef VTK_LEGACY_SILENT */
 
 /* Debug leaks support.  */
 /* #undef VTK_DEBUG_LEAKS */
 
+/* Debug for-range iterator support.  */
+/* #undef VTK_DEBUG_RANGE_ITERATORS */
+
+/* Debug for-range iterator support.  */
+/* #undef VTK_ALWAYS_OPTIMIZE_ARRAY_ITERATORS */
+
 /* Print warning on vtkArrayDispatch failure.  */
 /* #undef VTK_WARN_ON_DISPATCH_FAILURE */
 
@@ -112,21 +118,6 @@
 /*--------------------------------------------------------------------------*/
 /* Setup VTK based on platform features and configuration.                  */
 
-/* We now always use standard streams.  */
-#ifndef VTK_LEGACY_REMOVE
-# define VTK_USE_ANSI_STDLIB
-#endif
-
-/* Define a "vtkstd_bool" for backwards compatibility.  Only use bool
-   if this file is included by a c++ file. */
-#ifndef VTK_LEGACY_REMOVE
-# if defined(__cplusplus)
-  typedef bool vtkstd_bool;
-# else
-  typedef int vtkstd_bool;
-# endif
-#endif
-
 /* The maximum length of a file name in bytes including the
  * terminating null.
  */
@@ -138,33 +129,17 @@
 # define VTK_MAXPATH 32767 // Possible with Windows "extended paths"
 #endif
 
-/* TODO: wrap in #ifndef VTK_LEGACY_REMOVE */
-#if 1
+/* Legacy macros that are not required as VTK requires a C++11 compiler */
+#ifndef VTK_LEGACY_REMOVE
 # define VTK_OVERRIDE override
 # define VTK_FINAL final
 # define VTK_DELETE_FUNCTION =delete
 #endif
 
-/** extern template declarations for C++11
+/** extern template declarations for C++11. Only MinGW32 doesn't support this
  */
-#if ((__cplusplus >= 201103L) || (defined(_MSC_VER) && _MSC_VER >= 1700)) && !defined(__MINGW32__)
+#if !defined(__MINGW32__)
 #define VTK_USE_EXTERN_TEMPLATE
 #endif
 
-/** std::auto_ptr is deprecated in C++11 and will be removed in C++17
- *  use std::unique_ptr in C++11 and later compilers.
- */
-#if __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >=1700)\
- || (defined(_CPPLIB_VER) && _CPPLIB_VER >= 520)
-# define VTK_HAS_STD_UNIQUE_PTR
-#endif
-
-/* MS Visual Studio 2015 finally supports C99/C++11's snprintf but
- * for older versions, use _snprintf instead. Annoyingly, its semantics
- * are slightly different, but still better than using sprintf.
- */
-#if defined(_MSC_VER) && (_MSC_VER < 1900)
-# define snprintf _snprintf
-#endif
-
 #endif // vtkConfigure_h
