@@ -32,7 +32,7 @@
  * adding points  (which do not have Sharpness and Midpoint parameters)
  * will default to Midpoint = 0.5 (halfway between the control points) and
  * Sharpness = 0.0 (linear).
-*/
+ */
 
 #ifndef vtkPiecewiseFunction_h
 #define vtkPiecewiseFunction_h
@@ -45,22 +45,22 @@ class vtkPiecewiseFunctionInternals;
 class VTKCOMMONDATAMODEL_EXPORT vtkPiecewiseFunction : public vtkDataObject
 {
 public:
-  static vtkPiecewiseFunction *New();
-  vtkTypeMacro(vtkPiecewiseFunction,vtkDataObject);
+  static vtkPiecewiseFunction* New();
+  vtkTypeMacro(vtkPiecewiseFunction, vtkDataObject);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  void DeepCopy( vtkDataObject *f ) override;
-  void ShallowCopy( vtkDataObject *f ) override;
+  void DeepCopy(vtkDataObject* f) override;
+  void ShallowCopy(vtkDataObject* f) override;
 
   /**
    * Return what type of dataset this is.
    */
-  int GetDataObjectType() override {return VTK_PIECEWISE_FUNCTION;};
+  int GetDataObjectType() override { return VTK_PIECEWISE_FUNCTION; }
 
   /**
    * Get the number of points used to specify the function
    */
-  int  GetSize();
+  int GetSize();
 
   //@{
   /**
@@ -68,9 +68,9 @@ public:
    * then the function value is changed at that location.
    * Return the index of the point (0 based), or -1 on error.
    */
-  int AddPoint( double x, double y );
-  int AddPoint( double x, double y, double midpoint, double sharpness );
-  int RemovePoint( double x );
+  int AddPoint(double x, double y);
+  int AddPoint(double x, double y, double midpoint, double sharpness);
+  int RemovePoint(double x);
   //@}
 
   /**
@@ -84,13 +84,13 @@ public:
    * method that does not allow the specification of the sharpness and
    * midpoint values for the two nodes.
    */
-  void AddSegment( double x1, double y1, double x2, double y2 );
+  void AddSegment(double x1, double y1, double x2, double y2);
 
   /**
    * Returns the value of the function at the specified location using
    * the specified interpolation.
    */
-  double GetValue( double x );
+  double GetValue(double x);
 
   //@{
   /**
@@ -99,8 +99,8 @@ public:
    * values at the node. Returns -1 if the index is
    * out of range, returns 1 otherwise.
    */
-  int GetNodeValue( int index, double val[4] );
-  int SetNodeValue( int index, double val[4] );
+  int GetNodeValue(int index, double val[4]);
+  int SetNodeValue(int index, double val[4]);
   //@}
 
   //@{
@@ -111,7 +111,7 @@ public:
    * note that the vtkPiecewiseFunction no longer stores the nodes
    * in a double array internally.
    */
-  double *GetDataPointer();
+  double* GetDataPointer();
   void FillFromDataPointer(int, double*);
   //@}
 
@@ -119,7 +119,7 @@ public:
   /**
    * Returns the min and max node locations of the function.
    */
-  vtkGetVector2Macro( Range, double );
+  vtkGetVector2Macro(Range, double);
   //@}
 
   /**
@@ -136,8 +136,10 @@ public:
    * logIncrements is true, the intervals between entries will be constant in
    * logarithmic space.
    */
-  void GetTable( double x1, double x2, int size, float *table, int stride=1, int logIncrements=0 );
-  void GetTable( double x1, double x2, int size, double *table, int stride=1, int logIncrements=0 );
+  void GetTable(
+    double x1, double x2, int size, float* table, int stride = 1, int logIncrements = 0);
+  void GetTable(
+    double x1, double x2, int size, double* table, int stride = 1, int logIncrements = 0);
   //@}
 
   /**
@@ -146,8 +148,7 @@ public:
    * are regularly spaced between x1 and x2.  Parameter "stride" is
    * is step through the input table.
    */
-  void BuildFunctionFromTable( double x1, double x2, int size,
-                               double *table, int stride=1 );
+  void BuildFunctionFromTable(double x1, double x2, int size, double* table, int stride = 1);
 
   //@{
   /**
@@ -158,9 +159,9 @@ public:
    * specified and returns the value at the highest point for a request
    * above all points specified. On is the default.
    */
-  vtkSetMacro( Clamping, vtkTypeBool );
-  vtkGetMacro( Clamping, vtkTypeBool );
-  vtkBooleanMacro( Clamping, vtkTypeBool );
+  vtkSetMacro(Clamping, vtkTypeBool);
+  vtkGetMacro(Clamping, vtkTypeBool);
+  vtkBooleanMacro(Clamping, vtkTypeBool);
   //@}
 
   /**
@@ -168,9 +169,9 @@ public:
    * Default is false.
    * @{
    */
-  vtkSetMacro(UseLogScale, bool)
-  vtkGetMacro(UseLogScale, bool)
-  vtkBooleanMacro(UseLogScale, bool)
+  vtkSetMacro(UseLogScale, bool);
+  vtkGetMacro(UseLogScale, bool);
+  vtkBooleanMacro(UseLogScale, bool);
   /**@}*/
 
   /**
@@ -181,7 +182,7 @@ public:
    * 2 : NonIncreasing   (Always decreasing or zero slope)
    * 3 : Varied          (Contains both decreasing and increasing slopes)
    */
-  const char  *GetType();
+  const char* GetType();
 
   /**
    * Returns the first point location which precedes a non-zero segment of the
@@ -201,7 +202,7 @@ public:
    * Retrieve an instance of this class from an information object.
    */
   static vtkPiecewiseFunction* GetData(vtkInformation* info);
-  static vtkPiecewiseFunction* GetData(vtkInformationVector* v, int i=0);
+  static vtkPiecewiseFunction* GetData(vtkInformationVector* v, int i = 0);
   //@}
 
   //@{
@@ -218,7 +219,7 @@ public:
    * Estimates the minimum size of a table such that it would correctly sample this function.
    * The returned value should be passed as parameter 'n' when calling GetTable().
    */
-  int EstimateMinNumberOfSamples(double const & x1, double const & x2);
+  int EstimateMinNumberOfSamples(double const& x1, double const& x2);
 
 protected:
   vtkPiecewiseFunction();
@@ -237,16 +238,16 @@ protected:
   double FindMinimumXDistance();
 
   // The internal STL structures
-  vtkPiecewiseFunctionInternals *Internal;
+  vtkPiecewiseFunctionInternals* Internal;
 
   // Determines the function value outside of defined points
   // Zero = always return 0.0 outside of defined points
   // One  = clamp to the lowest value below defined points and
   //        highest value above defined points
-  vtkTypeBool   Clamping;
+  vtkTypeBool Clamping;
 
   // Array of points ((X,Y) pairs)
-  double *Function;
+  double* Function;
 
   // Min and max range of function point locations
   double Range[2];
@@ -261,5 +262,3 @@ private:
 };
 
 #endif
-
-
